Changelog
=========

Version 0.2.1
-------------
* Fixed API key detection.

Version 0.2.0
-------------
* Renamed widget decorators.

Version 0.1.0
-------------
* First release, split off from django-analytical_.

.. _django-analytical: http://pypi.python.org/pypi/django-analytical
